@@ -32,11 +32,11 @@ class Profile:
     """
 
     def __init__(
-        self, file_paths, parser, q_axis_name="qdcd", theta_axis_name="dcdtheta", pixel_max=1000000
+        self, file_paths, parser, q_axis_name="qdcd", theta_axis_name="dcdtheta", pixel_max=1000000, hot_pixel_threshold=200000
     ):
         self.scans = []
         for f in file_paths:
-            self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max))
+            self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max, hot_pixel_threshold=hot_pixel_threshold))
         self.q_vectors = None
         self.reflected_intensity = None
 
@@ -212,6 +212,7 @@ class Scan:
         theta_axis_name="dcdtheta",
         energy=None,
         pixel_max=1000000,
+        hot_pixel_threshold=200000
     ):
         self.file_path = file_path
         self.metadata, self.data = parser(self.file_path)
@@ -239,6 +240,7 @@ class Scan:
         self.R = unp.uarray(np.zeros(self.q.size), np.zeros(self.q.size),)
         self.n_pixels = np.zeros(self.q.size)
         self.pixel_max = pixel_max
+        self.hot_pixel_threshold = hot_pixel_threshold
 
     def __str__(self):
         """
@@ -314,7 +316,7 @@ class Scan:
         iterator = _get_iterator(unp.nominal_values(self.q), progress)
         to_remove = []
         for i in iterator:
-            im = image.Image(self.data["file"][i], self.data, self.metadata, pixel_maximum=self.pixel_max)
+            im = image.Image(self.data["file"][i], self.data, self.metadata, pixel_maximum=self.pixel_max, hot_pixel_threshold=self.hot_pixel_threshold)
             if im.skip:
                 to_remove.append(i)
                 continue
